diff --git a/dune/common/fvector.hh b/dune/common/fvector.hh
index c262013b0a7cd2a61fd6d0fc0cbcd73d7408cd74..72c273675835a4f7a8b392930c3b9cb730c1c4c7 100644
--- a/dune/common/fvector.hh
+++ b/dune/common/fvector.hh
@@ -290,7 +290,35 @@ namespace Dune {
   };
 
   /* ----- FV / FV ----- */
-  /* not necessary as these operations are already covered via the cast operator */
+  /* mostly not necessary as these operations are already covered via the cast operator */
+
+  //! Binary compare, when using FieldVector<K,1> like K
+  template<class K>
+  inline bool operator> (const FieldVector<K,1>& a, const FieldVector<K,1>& b)
+  {
+    return a[0]>b[0];
+  }
+
+  //! Binary compare, when using FieldVector<K,1> like K
+  template<class K>
+  inline bool operator>= (const FieldVector<K,1>& a, const FieldVector<K,1>& b)
+  {
+    return a[0]>=b[0];
+  }
+
+  //! Binary compare, when using FieldVector<K,1> like K
+  template<class K>
+  inline bool operator< (const FieldVector<K,1>& a, const FieldVector<K,1>& b)
+  {
+    return a[0]<b[0];
+  }
+
+  //! Binary compare, when using FieldVector<K,1> like K
+  template<class K>
+  inline bool operator<= (const FieldVector<K,1>& a, const FieldVector<K,1>& b)
+  {
+    return a[0]<=b[0];
+  }
 
   /* ----- FV / scalar ----- */